summaryrefslogtreecommitdiff
path: root/res/ari/resource_sounds.h
diff options
context:
space:
mode:
Diffstat (limited to 'res/ari/resource_sounds.h')
-rw-r--r--res/ari/resource_sounds.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/res/ari/resource_sounds.h b/res/ari/resource_sounds.h
index fa7cda23c..5e8ddd43d 100644
--- a/res/ari/resource_sounds.h
+++ b/res/ari/resource_sounds.h
@@ -39,8 +39,8 @@
#include "asterisk/ari.h"
-/*! \brief Argument struct for ast_ari_get_sounds() */
-struct ast_get_sounds_args {
+/*! \brief Argument struct for ast_ari_sounds_list() */
+struct ast_ari_sounds_list_args {
/*! \brief Lookup sound for a specific language. */
const char *lang;
/*! \brief Lookup sound in a specific format. */
@@ -53,9 +53,9 @@ struct ast_get_sounds_args {
* \param args Swagger parameters
* \param[out] response HTTP response
*/
-void ast_ari_get_sounds(struct ast_variable *headers, struct ast_get_sounds_args *args, struct ast_ari_response *response);
-/*! \brief Argument struct for ast_ari_get_stored_sound() */
-struct ast_get_stored_sound_args {
+void ast_ari_sounds_list(struct ast_variable *headers, struct ast_ari_sounds_list_args *args, struct ast_ari_response *response);
+/*! \brief Argument struct for ast_ari_sounds_get() */
+struct ast_ari_sounds_get_args {
/*! \brief Sound's id */
const char *sound_id;
};
@@ -66,6 +66,6 @@ struct ast_get_stored_sound_args {
* \param args Swagger parameters
* \param[out] response HTTP response
*/
-void ast_ari_get_stored_sound(struct ast_variable *headers, struct ast_get_stored_sound_args *args, struct ast_ari_response *response);
+void ast_ari_sounds_get(struct ast_variable *headers, struct ast_ari_sounds_get_args *args, struct ast_ari_response *response);
#endif /* _ASTERISK_RESOURCE_SOUNDS_H */